# -*- coding: utf-8 -*-

import geompy
import math

import salome, SMESH
import smesh
import StdMeshers


# define four corner points
p00 = geompy.MakeVertex(0.0, 0.0, 0.0)
p10 = geompy.MakeVertex(0.7, 0.0, 0.0)
p11 = geompy.MakeVertex(0.7, 1.0, 0.0)
p01 = geompy.MakeVertex(0.0, 1.0, 0.0)

# define lines between corner points
Ly0 = geompy.MakeLineTwoPnt(p00, p10)
Lx1 = geompy.MakeLineTwoPnt(p10, p11)
Ly1 = geompy.MakeLineTwoPnt(p11, p01)
Lx0 = geompy.MakeLineTwoPnt(p01, p00)

#define face between lines
Face1 = geompy.MakeFaceWires([Ly0, Lx1, Ly1, Lx0], 1)

#  create a group to be meshed by shell elements in Code Aster
shell = geompy.CreateGroup(Face1, geompy.ShapeType["FACE"])
geompy.UnionIDs(shell, [1])
Face1 = geompy.GetMainShape(shell)

# create a group for boundary conditions in CA
Linex1 = geompy.CreateGroup(Face1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Linex1, [10])
Face1 = geompy.GetMainShape(Linex1)
Liney1 = geompy.CreateGroup(Face1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Liney1, [3])
Face1 = geompy.GetMainShape(Liney1)
Linex0 = geompy.CreateGroup(Face1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Linex0, [6])
Face1 = geompy.GetMainShape(Linex0)
Liney0 = geompy.CreateGroup(Face1, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Liney0, [8])
Face1 = geompy.GetMainShape(Liney0)


# add all the components to the study
geompy.addToStudy( p00, "p00" )
geompy.addToStudy( p10, "p10" )
geompy.addToStudy( p11, "p11" )
geompy.addToStudy( p01, "p01" )
geompy.addToStudy( Ly0, "Ly0" )
geompy.addToStudy( Lx1, "Lx1" )
geompy.addToStudy( Ly1, "Ly1" )
geompy.addToStudy( Lx0, "Lx0" )
geompy.addToStudy( Face1, "Face1" )

# add the groups to the study
# Linexi are same components as Lzi in main geometry
geompy.addToStudyInFather( Face1, shell, "shell" )
geompy.addToStudyInFather( Face1, Linex1, "Linex1" )
geompy.addToStudyInFather( Face1, Liney1, "Liney1" )
geompy.addToStudyInFather( Face1, Linex0, "Linex0" )
geompy.addToStudyInFather( Face1, Liney0, "Liney0" )
